<?php

namespace Litecms\Affiliatebonus\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Affiliatebonus\Models\Affiliatebonus;

class AffiliatebonusPolicy
{

    /**
     * Determine if the given user can view the affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function view(UserPolicy $user, Affiliatebonus $affiliatebonus)
    {
        if ($user->canDo('affiliatebonus.affiliatebonus.view') && $user->isAdmin()) {
            return true;
        }

        return $affiliatebonus->user_id == user_id() && $affiliatebonus->user_type == user_type();
    }

    /**
     * Determine if the given user can create a affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('affiliatebonus.affiliatebonus.create');
    }

    /**
     * Determine if the given user can update the given affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function update(UserPolicy $user, Affiliatebonus $affiliatebonus)
    {
        if ($user->canDo('affiliatebonus.affiliatebonus.edit') && $user->isAdmin()) {
            return true;
        }

        return $affiliatebonus->user_id == user_id() && $affiliatebonus->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Affiliatebonus $affiliatebonus)
    {
        return $affiliatebonus->user_id == user_id() && $affiliatebonus->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Affiliatebonus $affiliatebonus)
    {
        if ($user->canDo('affiliatebonus.affiliatebonus.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given affiliatebonus.
     *
     * @param UserPolicy $user
     * @param Affiliatebonus $affiliatebonus
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Affiliatebonus $affiliatebonus)
    {
        if ($user->canDo('affiliatebonus.affiliatebonus.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
