<?php

namespace Litecms\Affiliatebonus\Providers;

use Illuminate\Support\ServiceProvider;

class AffiliatebonusServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'affiliatebonus');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'affiliatebonus');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.affiliatebonus', function ($app) {
            return $this->app->make('Litecms\Affiliatebonus\Affiliatebonus');
        });

                // Bind Affiliatebonus to repository
        $this->app->bind(
            'Litecms\Affiliatebonus\Interfaces\AffiliatebonusRepositoryInterface',
            \Litecms\Affiliatebonus\Repositories\Eloquent\AffiliatebonusRepository::class
        );

        $this->app->register(\Litecms\Affiliatebonus\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Affiliatebonus\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.affiliatebonus'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/affiliatebonus.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/affiliatebonus')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/affiliatebonus')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
